@@ -6,9 +6,6 @@ class YtSettings(metaclass=Singleton):
         self.YT_MAX_RESULTS = 5
         self.YT_BASE_URL = 'https://youtube.com'
 
-        self.FILE_DIR = 'download'
-        self.FILE_EXT = 'mp3'
-
         self.BONUS_RATES = {
             'OFFICIAL': .5,
             'REMIX': .5,
